NAME

Zuzu::AST::Stmt::Let - AST node for let statements

DESCRIPTION

Represents one statement form in the abstract syntax tree and delegates execution to Zuzu::Runtime.

INHERITANCE

Inherits from Moo::Object.

ROLES

Consumes Zuzu::AST::Role::Node.

ATTRIBUTES

name

Type: Str.

Identifier name declared or referenced by the node/value.

init

Type: Maybe[ConsumerOf["Zuzu::AST::Role::Node"]].

Initializer expression for declarations, if present.

is_const

Type: Bool.

True when the declared binding is immutable.

METHODS

evaluate

Dispatches this AST node to the matching runtime evaluator.

SEE ALSO

Zuzu::AST::Role::Node.

Subclasses: none in this distribution.

COPYRIGHT AND LICENCE

Zuzu::AST::Stmt::Let is copyright Toby Inkster.

It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.